# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-12 23:35
from __future__ import unicode_literals

import autoslug.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('teryt_tree', '0003_auto_20161210_1515'),
    ]

    operations = [
        migrations.CreateModel(
            name='SIMC',
            fields=[
                ('id', models.CharField(max_length=7, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=100)),
                ('updated_on', models.DateField(verbose_name='Updated date')),
                ('sym_pod', models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE, to='teryt_tree.SIMC')),
            ],
        ),
        migrations.AlterField(
            model_name='category',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='name'),
        ),
        migrations.AlterField(
            model_name='jednostkaadministracyjna',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='name', unique=True),
        ),
        migrations.AddField(
            model_name='simc',
            name='terc',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='teryt_tree.JednostkaAdministracyjna'),
        ),
    ]
